pub struct ChainFVect<R: HomSigns, F: Ring + Clone, M: EffortfulMatrixStore<F>> { /* private fields */ }Implementations
Sourceimpl<R, F, M> ChainFVect<R, F, M>
impl<R, F, M> ChainFVect<R, F, M>
Sourcepub fn concentrated_in_0(dimension: usize) -> Self
pub fn concentrated_in_0(dimension: usize) -> Self
a single vector space of dimension concentrated in degree 0
Sourcepub fn dimensions_each_index(&self) -> Vec<(i64, usize)>
pub fn dimensions_each_index(&self) -> Vec<(i64, usize)>
what are the dimensions of the vector spaces at each HomologicalIndexing
Sourcepub fn dimensions_of_that(&self, which_index: i64) -> usize
pub fn dimensions_of_that(&self, which_index: i64) -> usize
what are the dimensions of the vector spaces at which_index specifically
Sourcepub fn bettis_each_index(&self) -> Vec<(i64, usize)>
pub fn bettis_each_index(&self) -> Vec<(i64, usize)>
all the betti numbers
Sourcepub fn shift_all(&mut self, how_much: i64)
pub fn shift_all(&mut self, how_much: i64)
shift the complex by how_much
depending on the sign of this and the marker R of HomSigns
this may be in the direction of the differential or not
Sourcepub fn prepend_zero_spaces(&mut self, how_many: i64)
pub fn prepend_zero_spaces(&mut self, how_many: i64)
put more zero vector spaces before the first nonzero differential (not trivially 0, it might be 0 but not obviously) puts them opposite the direction of the differential
Sourcepub fn align_together(&mut self, other: &mut Self)
pub fn align_together(&mut self, other: &mut Self)
get these two to line up so they start with the same HomologicalIndexing
Sourcepub fn prepend_space(
&mut self,
new_dimension: usize,
new_differential: M,
) -> Result<(), bool>
pub fn prepend_space( &mut self, new_dimension: usize, new_differential: M, ) -> Result<(), bool>
like prepend_zero_space put a vector space before the first differential
(one that is not implicitly 0)
but here we are putting a nontrivial vector space and a differential to the next space
Errors
Err(false) if the dimension of the space being appended/prepended
did not match the dimensions of the new_differential matrix
Err(true) if d^2 \neq 0
Sourceimpl<F, M> ChainFVect<CohomologicalIndex, F, M>
impl<F, M> ChainFVect<CohomologicalIndex, F, M>
pub fn negate_homological_indices(self) -> ChainFVect<HomologicalIndex, F, M>
Sourceimpl<F, M> ChainFVect<HomologicalIndex, F, M>
impl<F, M> ChainFVect<HomologicalIndex, F, M>
pub fn negate_homological_indices(self) -> ChainFVect<CohomologicalIndex, F, M>